@@ -188,6 +188,13 @@ def ouadmin_umc_client(ou):
     return client
 
 
+@pytest.fixture
+def ou_helpdesk_operator_umc_client(ou):
+    client = ClientHelper()
+    client.authenticate(ou.helpdesk_operator_username, 'univention')
+    return client
+
+
 @pytest.fixture
 def admin_rest_client(ucr):
     return RestClientHelper(
@@ -206,16 +213,27 @@ def ouadmin_rest_client(ucr, ou):
     )
 
 
+@pytest.fixture
+def ou_helpdesk_operator_rest_client(ucr, ou):
+    return RestClientHelper(
+        'https://%(hostname)s.%(domainname)s/univention/udm/' % ucr,
+        username=ou.helpdesk_operator_username,
+        password='univention',
+    )
+
+
 @pytest.fixture
 def ou(ldap_base, udm):
     return SimpleNamespace(
         dn=f'ou=ou1,{ldap_base}',
         dn2=f'ou=ou2,{ldap_base}',
-        admin_username='ou1admin',
-        admin_dn=f'uid=ou1admin,cn=users,{ldap_base}',
-        admin_dn2=f'uid=ou2admin,cn=users,{ldap_base}',
+        admin_username='ou1-admin',
+        admin_dn=f'uid=ou1-admin,cn=users,{ldap_base}',
+        admin_dn2=f'uid=ou2-admin,cn=users,{ldap_base}',
         user_username='user1-ou1',
         user_dn=f'uid=user1-ou1,cn=users,ou=ou1,{ldap_base}',
+        helpdesk_operator_username='ou1-helpdesk-operator',
+        helpdesk_operator_dn=f'uid=ou1-helpdesk-operator,cn=users,{ldap_base}',
         user_default_container=f'cn=users,ou=ou1,{ldap_base}',
         group_default_container=f'cn=groups,ou=ou1,{ldap_base}',
     )
@@ -250,7 +268,7 @@ def setup_role(ou, udm, ucr, ldap_base):
             check_call([CONFIGURE_AUTH, '--store-local', 'create-roles', '--config', tmp.name])
         _, username = udm.create_user(
             guardianRoles=[role],
-            groups=[ucr.get('directory/manager/rest/authorized-groups/test-api-access')],
+            groups=[ucr['directory/manager/rest/authorized-groups/test-api-access']],
             policy_reference=[f'cn=organizational-unit-amdins,cn=UMC,cn=policies,{ldap_base}'],
         )
         check_call(['systemctl', 'restart', 'univention-management-console-server.service', 'univention-directory-manager-rest.service'])
